import React, { useState } from 'react';
import { Phone, MessageCircle, Send, Award, Users, Star, Shield, Clock, Heart } from 'lucide-react';
import LazyImage from './LazyImage';

interface HeroProps {
  language: 'az' | 'en' | 'ru';
}

const Hero: React.FC<HeroProps> = ({ language }) => {
  const [formData, setFormData] = useState({
    name: '',
    phone: '',
    email: '',
    procedure: ''
  });

  const content = {
    az: {
      badge: 'Uzman Plastik Cərrah',
      title: 'Dr. Vüqar Ələkbərov',
      subtitle: 'Estetik, Plastik və Rekonstruktiv Cərrahiyyə',
      description: '10+ illik təcrübə və 8000+ uğurlu əməliyyat ilə sizə xidmət edirik',
      stats: [
        { number: '8000+', label: 'Uğurlu əməliyyat', icon: Award },
        { number: '10+', label: 'İl təcrübə', icon: Users },
        { number: '5.0', label: 'Xəstə reytinqi', icon: Star }
      ],
      form: {
        title: 'Pulsuz Konsultasiya',
        subtitle: 'Həkimimizlə birbaşa əlaqə saxlayın',
        name: 'Ad Soyad',
        phone: 'Telefon nömrəniz',
        email: 'E-poçt ünvanınız',
        procedure: 'İstədiyiniz əməliyyat',
        submit: 'Pulsuz konsultasiya al',
        procedures: [
          'Rinoplastika (Burun estetikası)',
          'Mamoplastika (Döş estetikası)',
          'Facelift (Üz gəncləşdirmə)',
          'Liposaksiya (Yağ çıxarma)',
          'BBL (Brazilian Butt Lift)',
          'Abdominoplastika (Qarın estetikası)',
          'Blefaroplastika (Göz qapağı)',
          'Yanaq və çənə estetikası'
        ]
      },
      whatsapp: 'WhatsApp ilə əlaqə',
      consultation: 'Pulsuz konsultasiya',
      trustBadges: [
        { icon: Shield, text: 'Təhlükəsiz' },
        { icon: Clock, text: 'Sürətli cavab' },
        { icon: Heart, text: 'Fərdi yanaşma' }
      ]
    },
    en: {
      badge: 'Specialist Plastic Surgeon',
      title: 'Dr. Vüqar Ələkbərov',
      subtitle: 'Aesthetic, Plastic & Reconstructive Surgery',
      description: 'Serving you with 10+ years of experience and 8000+ successful operations',
      stats: [
        { number: '8000+', label: 'Successful operations', icon: Award },
        { number: '10+', label: 'Years experience', icon: Users },
        { number: '5.0', label: 'Patient rating', icon: Star }
      ],
      form: {
        title: 'Free Consultation',
        subtitle: 'Get in direct contact with our doctor',
        name: 'Full Name',
        phone: 'Your phone number',
        email: 'Your email address',
        procedure: 'Desired Procedure',
        submit: 'Get Free Consultation',
        procedures: [
          'Rhinoplasty (Nose aesthetics)',
          'Mammoplasty (Breast aesthetics)',
          'Facelift (Facial rejuvenation)',
          'Liposuction (Fat removal)',
          'BBL (Brazilian Butt Lift)',
          'Abdominoplasty (Tummy tuck)',
          'Blepharoplasty (Eyelid surgery)',
          'Cheek & chin aesthetics'
        ]
      },
      whatsapp: 'Contact via WhatsApp',
      consultation: 'Free consultation',
      trustBadges: [
        { icon: Shield, text: 'Secure' },
        { icon: Clock, text: 'Quick response' },
        { icon: Heart, text: 'Personal approach' }
      ]
    },
    ru: {
      badge: 'Специалист пластический хирург',
      title: 'Др. Вугар Алекберов',
      subtitle: 'Эстетическая, пластическая и реконструктивная хирургия',
      description: 'Обслуживаем вас с 10+ летним опытом и 8000+ успешными операциями',
      stats: [
        { number: '8000+', label: 'Успешных операций', icon: Award },
        { number: '10+', label: 'Лет опыта', icon: Users },
        { number: '5.0', label: 'Рейтинг пациентов', icon: Star }
      ],
      form: {
        title: 'Бесплатная консультация',
        subtitle: 'Свяжитесь напрямую с нашим врачом',
        name: 'Полное имя',
        phone: 'Ваш номер телефона',
        email: 'Ваш email адрес',
        procedure: 'Желаемая процедура',
        submit: 'Получить бесплатную консультацию',
        procedures: [
          'Ринопластика (Эстетика носа)',
          'Маммопластика (Эстетика груди)',
          'Фейслифт (Омоложение лица)',
          'Липосакция (Удаление жира)',
          'BBL (Бразильская подтяжка ягодиц)',
          'Абдоминопластика (Подтяжка живота)',
          'Блефаропластика (Хирургия век)',
          'Эстетика щек и подбородка'
        ]
      },
      whatsapp: 'Связь через WhatsApp',
      consultation: 'Бесплатная консультация',
      trustBadges: [
        { icon: Shield, text: 'Безопасно' },
        { icon: Clock, text: 'Быстрый ответ' },
        { icon: Heart, text: 'Индивидуальный подход' }
      ]
    }
  };

  const handleSubmit = (e: React.FormEvent) => {
    e.preventDefault();
    
    // WhatsApp message creation
    const message = `Salam! Saytdan müraciət:
    
Ad: ${formData.name}
Telefon: ${formData.phone}
Email: ${formData.email}
Prosedur: ${formData.procedure}`;
    
    const whatsappUrl = `https://wa.me/994509991115?text=${encodeURIComponent(message)}`;
    window.open(whatsappUrl, '_blank');
    
    // Reset form
    setFormData({
      name: '',
      phone: '',
      email: '',
      procedure: ''
    });
  };

  const handleInputChange = (e: React.ChangeEvent<HTMLInputElement | HTMLSelectElement>) => {
    setFormData({
      ...formData,
      [e.target.name]: e.target.value
    });
  };

  const scrollToContact = () => {
    const element = document.getElementById('contact');
    if (element) {
      element.scrollIntoView({ behavior: 'smooth' });
    }
  };

  return (
    <section id="home" className="relative min-h-screen flex items-center justify-center overflow-hidden pt-16 lg:pt-20">
      {/* Background */}
      <div className="absolute inset-0 bg-gradient-to-br from-gray-900 via-blue-900 to-gray-800">
        <div className="absolute inset-0 opacity-20">
          <div className="absolute inset-0" style={{
            backgroundImage: `url("data:image/svg+xml,%3Csvg width='40' height='40' viewBox='0 0 40 40' xmlns='http://www.w3.org/2000/svg'%3E%3Cg fill='none' fill-rule='evenodd'%3E%3Cg fill='%23ffffff' fill-opacity='0.1'%3E%3Ccircle cx='20' cy='20' r='1.5'/%3E%3C/g%3E%3C/g%3E%3C/svg%3E")`,
          }}></div>
        </div>
      </div>

      {/* Content */}
      <div className="relative z-10 max-w-7xl mx-auto px-4 sm:px-6 lg:px-8 py-8 lg:py-16">
        <div className="grid lg:grid-cols-2 gap-8 lg:gap-16 items-center">
          {/* Left Content */}
          <div className="text-white text-center lg:text-left order-2 lg:order-1">
            {/* Professional Badge */}
            <div className="inline-flex items-center space-x-2 bg-blue-600/20 backdrop-blur-sm border border-blue-400/30 rounded-full px-3 py-1.5 mb-4 lg:mb-6">
              <Award className="w-3 h-3 lg:w-4 lg:h-4 text-blue-300" />
              <span className="text-blue-200 font-medium text-xs lg:text-sm">{content[language].badge}</span>
            </div>

            <h1 className="text-2xl sm:text-3xl md:text-4xl lg:text-5xl xl:text-6xl font-bold leading-tight mb-2 lg:mb-3 bg-gradient-to-r from-white to-blue-200 bg-clip-text text-transparent">
              {content[language].title}
            </h1>
            
            <h2 className="text-sm sm:text-base md:text-lg lg:text-xl xl:text-2xl font-light mb-3 lg:mb-4 text-blue-200">
              {content[language].subtitle}
            </h2>
            
            <p className="text-sm sm:text-base lg:text-lg mb-6 lg:mb-8 text-gray-300 leading-relaxed max-w-2xl mx-auto lg:mx-0">
              {content[language].description}
            </p>

            {/* Stats */}
            <div className="grid grid-cols-3 gap-2 sm:gap-4 lg:gap-6 mb-6 lg:mb-8">
              {content[language].stats.map((stat, index) => {
                const IconComponent = stat.icon;
                return (
                  <div key={index} className="text-center bg-white/10 backdrop-blur-sm rounded-lg lg:rounded-xl p-2 sm:p-3 lg:p-4">
                    <IconComponent className="w-4 h-4 sm:w-5 sm:h-5 lg:w-6 lg:h-6 text-blue-300 mx-auto mb-1 lg:mb-2" />
                    <div className="text-lg sm:text-xl lg:text-2xl xl:text-3xl font-bold text-white mb-1">
                      {stat.number}
                    </div>
                    <div className="text-xs sm:text-sm text-gray-300 font-medium">
                      {stat.label}
                    </div>
                  </div>
                );
              })}
            </div>
            
            {/* Action Buttons */}
            <div className="flex flex-col sm:flex-row gap-3 sm:gap-4 justify-center lg:justify-start">
              <a
                href="https://wa.me/994509991115"
                target="_blank"
                rel="noopener noreferrer"
                className="inline-flex items-center justify-center space-x-2 bg-green-600 text-white px-4 py-2.5 sm:px-6 sm:py-3 lg:px-8 lg:py-4 rounded-xl hover:bg-green-700 transition-all duration-300 font-semibold text-sm sm:text-base lg:text-lg hover:scale-105 shadow-2xl"
              >
                <MessageCircle className="w-4 h-4 sm:w-5 sm:h-5 lg:w-6 lg:h-6" />
                <span>{content[language].whatsapp}</span>
              </a>
              
              <button 
                onClick={scrollToContact}
                className="inline-flex items-center justify-center space-x-2 bg-white/10 backdrop-blur-sm border border-white/20 text-white px-4 py-2.5 sm:px-6 sm:py-3 lg:px-8 lg:py-4 rounded-xl hover:bg-white/20 transition-all duration-300 font-semibold text-sm sm:text-base lg:text-lg"
              >
                <Phone className="w-4 h-4 sm:w-5 sm:h-5 lg:w-6 lg:h-6" />
                <span>{content[language].consultation}</span>
              </button>
            </div>
          </div>

          {/* Right Form */}
          <div className="bg-white/95 backdrop-blur-lg rounded-xl lg:rounded-2xl xl:rounded-3xl p-4 sm:p-6 lg:p-8 shadow-2xl border border-white/20 order-1 lg:order-2">
            <div className="text-center mb-4 sm:mb-6 lg:mb-8">
              <div className="inline-flex items-center space-x-2 bg-blue-50 rounded-full px-3 py-1.5 sm:px-4 sm:py-2 mb-2 sm:mb-3 lg:mb-4">
                <Star className="w-3 h-3 sm:w-4 sm:h-4 lg:w-5 lg:h-5 text-blue-600" />
                <span className="text-blue-800 font-semibold text-xs sm:text-sm lg:text-base">
                  {content[language].form.title}
                </span>
              </div>
              <h3 className="text-lg sm:text-xl lg:text-2xl font-bold text-gray-900 mb-1 sm:mb-2">
                {content[language].form.title}
              </h3>
              <p className="text-xs sm:text-sm lg:text-base text-gray-600">
                {content[language].form.subtitle}
              </p>
            </div>

            <form onSubmit={handleSubmit} className="space-y-3 sm:space-y-4 lg:space-y-6">
              <div>
                <input
                  type="text"
                  name="name"
                  placeholder={content[language].form.name}
                  value={formData.name}
                  onChange={handleInputChange}
                  className="w-full px-3 py-2.5 sm:px-4 sm:py-3 lg:px-6 lg:py-4 border-2 border-gray-200 rounded-lg lg:rounded-xl focus:ring-2 focus:ring-blue-500 focus:border-transparent transition-all duration-200 text-sm sm:text-base lg:text-lg"
                  required
                />
              </div>
              
              <div>
                <input
                  type="tel"
                  name="phone"
                  placeholder={content[language].form.phone}
                  value={formData.phone}
                  onChange={handleInputChange}
                  className="w-full px-3 py-2.5 sm:px-4 sm:py-3 lg:px-6 lg:py-4 border-2 border-gray-200 rounded-lg lg:rounded-xl focus:ring-2 focus:ring-blue-500 focus:border-transparent transition-all duration-200 text-sm sm:text-base lg:text-lg"
                  required
                />
              </div>
              
              <div>
                <input
                  type="email"
                  name="email"
                  placeholder={content[language].form.email}
                  value={formData.email}
                  onChange={handleInputChange}
                  className="w-full px-3 py-2.5 sm:px-4 sm:py-3 lg:px-6 lg:py-4 border-2 border-gray-200 rounded-lg lg:rounded-xl focus:ring-2 focus:ring-blue-500 focus:border-transparent transition-all duration-200 text-sm sm:text-base lg:text-lg"
                  required
                />
              </div>
              
              <div>
                <select
                  name="procedure"
                  value={formData.procedure}
                  onChange={handleInputChange}
                  className="w-full px-3 py-2.5 sm:px-4 sm:py-3 lg:px-6 lg:py-4 border-2 border-gray-200 rounded-lg lg:rounded-xl focus:ring-2 focus:ring-blue-500 focus:border-transparent transition-all duration-200 text-sm sm:text-base lg:text-lg"
                  required
                >
                  <option value="">{content[language].form.procedure}</option>
                  {content[language].form.procedures.map((procedure) => (
                    <option key={procedure} value={procedure}>
                      {procedure}
                    </option>
                  ))}
                </select>
              </div>
              
              <button
                type="submit"
                className="w-full bg-gradient-to-r from-blue-600 to-blue-700 text-white px-4 py-2.5 sm:px-6 sm:py-3 lg:py-4 rounded-lg lg:rounded-xl hover:from-blue-700 hover:to-blue-800 transition-all duration-300 font-semibold text-sm sm:text-base lg:text-lg flex items-center justify-center space-x-2 hover:scale-105 shadow-xl"
              >
                <Send className="w-4 h-4 sm:w-5 sm:h-5 lg:w-6 lg:h-6" />
                <span>{content[language].form.submit}</span>
              </button>
            </form>

            {/* Trust Indicators */}
            <div className="mt-4 sm:mt-6 lg:mt-8 pt-3 sm:pt-4 lg:pt-6 border-t border-gray-200">
              <div className="grid grid-cols-3 gap-2 sm:gap-4 text-xs sm:text-sm text-gray-600">
                {content[language].trustBadges.map((badge, index) => {
                  const IconComponent = badge.icon;
                  return (
                    <div key={index} className="flex flex-col items-center space-y-1 sm:space-y-2">
                      <div className="w-6 h-6 sm:w-8 sm:h-8 lg:w-10 lg:h-10 bg-gradient-to-br from-blue-500 to-blue-600 rounded-full flex items-center justify-center">
                        <IconComponent className="w-3 h-3 sm:w-4 sm:h-4 lg:w-5 lg:h-5 text-white" />
                      </div>
                      <span className="font-medium text-center">{badge.text}</span>
                    </div>
                  );
                })}
              </div>
            </div>
          </div>
        </div>
      </div>

      {/* Professional Doctor Image - Optimized for Core Web Vitals */}
      <div className="absolute right-0 top-0 bottom-0 w-1/4 hidden xl:block">
        <div className="relative h-full">
          <LazyImage
            src="/v.jpg"
            alt="Dr. Vüqar Ələkbərov - Plastik Cərrah"
            className="absolute right-0 top-1/2 transform -translate-y-1/2 h-4/5 w-auto object-cover rounded-l-3xl shadow-2xl"
            fetchPriority="high"
            loading="eager"
          />
          <div className="absolute right-0 top-1/2 transform -translate-y-1/2 h-4/5 w-full bg-gradient-to-l from-transparent via-blue-900/20 to-blue-900/40 rounded-l-3xl"></div>
        </div>
      </div>
    </section>
  );
};

export default Hero;